# Turbine Engine Data

Contains data of:

- Civilian turboprops / turboshafts
- Civilian turbojets
- Military turboprops / turboshafts
- Military turbojets

All data compiled from Nathan Meier at [jet-engine.net](http://jet-engine.net/). A few erroneous or dubious entries have been removed.